@@ -5,6 +5,7 @@ import configargparse
 import argcomplete
 from anytree import NodeMixin
 
+from buildtools.post_github_comment import PostGitHubPRComment
 from buildtools.post_bitbucket_build_status import PostBitbucketBuildStatus
 from buildtools.post_bitbucket_comment import PostBitbucketPRComment
 from buildtools.post_teams_actionable_message import PostTeamsCard
@@ -33,7 +34,7 @@ class BTNodeParser(BTNode):
 class BuildTools:
     def __init__(self):
         self.base_parser = configargparse.ArgumentParser(add_help=False)
-        self.base_parser.add('--version', action='version', version=f"BuildTools Version: v{__version__}")
+        self.base_parser.add('--version', action='version', version=f"BuildTools Version: {__version__}")
         self.base_parser.add('--bitbucket-url', env_var='BITBUCKET_URL', help="URL for Bitbucket.")
         self.parser = configargparse.ArgumentParser(description="Tools that help with Jenkins build scripts.", parents=[self.base_parser])
 
@@ -100,6 +101,7 @@ def main(args):
     bt.register(PostBitbucketPRComment())
     bt.register(PostTeamsCard())
     bt.register(ParseAnsibleJson())
+    bt.register(PostGitHubPRComment())
     #bt.register(PostBitbucketPR())
     bt.run(args)
 
