@@ -62,6 +62,8 @@ class AnsibleJSONParser:
                 # Handle exception.
                 if 'exception' in host:
                     self.results.add_error(task_name, host_name, host['exception'])
+                if 'failed' in host and host['failed']:
+                    self.results.add_error(task_name, host_name, host['msg'])
                 # Only grab the diff from the "apply templated configuration to juniper device" task.
                 if task_name == JUNIPER_CONFIG_TASK_NAME:
                     # Only grab the diff if there is a 'prepared diff' available.
